Test Verifications
open | ../tests/html/test_verifications.html?foo=bar |
verifyLocation | */tests/html/test_verifications.html* |
verifyLocation | */tests/html/test_verifications.html?foo=bar |
verifyValue | theText | the text value
verifyNotValue | theText | not the text value
verifyValue | theHidden | the hidden value
verifyText | theSpan | this is the span
verifyNotText | theSpan | blah blah
verifyTextPresent | this is the span |
verifyTextNotPresent | this is not the span |
verifyElementPresent | theSpan |
verifyElementPresent | theText |
verifyElementNotPresent | unknown |
verifyTable | theTable.0.0 | th1
verifyTable | theTable.1.0 | a
verifyTable | theTable.2.1 | d
verifyTable | theTable.3.1 | f2
verifySelected | theSelect | index=1
verifySelected | theSelect | value=option2
verifySelected | theSelect | label=second option
verifySelected | theSelect | second option
verifySelected | theSelect | id=o2
verifySelectOptions | theSelect | first option,second option,third\,\,option
verifyAttribute | theText@class | foo
verifyNotAttribute | theText@class | fox
verifyTitle | theTitle |
verifyNotTitle | Blah Blah |